@@ -13,7 +13,7 @@ from __future__ import absolute_import, division, unicode_literals
 import operator
 
 from jx_base.language import is_expression, Language
-from mo_dots import Null, is_sequence
+from mo_dots import is_sequence
 from mo_future import (
     first,
     get_function_name,
@@ -22,6 +22,7 @@ from mo_future import (
     text,
     utf8_json_encoder,
 )
+from mo_imports import expect
 from mo_json import BOOLEAN, INTEGER, IS_NULL, NUMBER, OBJECT, STRING, scrub
 from mo_logs import Except, Log
 from mo_math import is_number
@@ -30,7 +31,10 @@ from mo_times import Date
 ALLOW_SCRIPTING = False
 EMPTY_DICT = {}
 
-Literal, TRUE, NULL, TupleOp, Variable = [Null] * 5  # IMPORTS
+Literal, TRUE, FALSE, NULL, TupleOp, Variable = expect(
+    "Literal", "TRUE", "FALSE", "NULL", "TupleOp", "Variable"
+)
+
 
 def extend(cls):
     """
