@@ -10,33 +10,31 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions import literal
 from jx_base.expressions.literal import Literal
-from mo_dots import coalesce
-from mo_future import is_text
+from mo_dots import coalesce, Null, is_data
+from mo_imports import export
 from mo_json import NUMBER
-from mo_times.dates import unicode2Date, Date
+from mo_times.dates import Date
 
 
 class DateOp(Literal):
     date_type = NUMBER
 
+    def __new__(cls, *args, **kwargs):
+        return object.__new__(cls)
+
     def __init__(self, term):
-        if hasattr(self, "date"):
-            return
-        if is_text(term):
-            self.date = term
-        else:
-            self.date = coalesce(term.get("literal"), term)
-        v = unicode2Date(self.date)
-        if isinstance(v, Date):
-            Literal.__init__(self, v.unix)
-        else:
-            Literal.__init__(self, v.seconds)
+        if is_data(term):
+            term = term['date']  # FOR WHEN WE MIGHT DO Literal({"date":term})
+        self.date = term
+        Literal.__init__(self, float(Date(self.date)))
 
     @classmethod
     def define(cls, expr):
-        return cls.lang[DateOp(expr.get("date"))]
+        term = expr.get("date")
+        if is_data(term):
+            term = coalesce(term.get("literal"), term)
+        return DateOp(term)
 
     def __data__(self):
         return {"date": self.date}
@@ -45,4 +43,4 @@ class DateOp(Literal):
         return Date(self.date)
 
 
-literal.DateOp=DateOp
+export("jx_base.expressions.literal", DateOp)
