@@ -10,14 +10,22 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import operators, jx_expression, _jx_expression, simplified
+from jx_base.expressions._utils import (
+    operators,
+    jx_expression,
+    _jx_expression,
+    simplified
+)
 from jx_base.language import BaseExpression, ID, is_expression, is_op
 from mo_dots import is_data, is_sequence, is_container
 from mo_future import items as items_, text
+from mo_imports import expect
 from mo_json import BOOLEAN, OBJECT, value2json
 from mo_logs import Log
 
-FALSE, Literal, is_literal, MissingOp, NotOp, NULL, Variable = [None]*7
+TRUE, FALSE, Literal, is_literal, MissingOp, NotOp, NULL, Variable = expect(
+    "TRUE", "FALSE", "Literal", "is_literal", "MissingOp", "NotOp", "NULL", "Variable"
+)
 
 
 class Expression(BaseExpression):
@@ -135,7 +143,13 @@ class Expression(BaseExpression):
         """
         :return: TRUE IF FALSE
         """
-        return self.lang[NotOp(self)]
+        inv = self.partial_eval()
+        if inv is TRUE:
+            return FALSE
+        elif inv is FALSE:
+            return TRUE
+        else:
+            return self.lang[NotOp(inv)]
 
     @simplified
     def partial_eval(self):
@@ -165,6 +179,5 @@ class Expression(BaseExpression):
         Log.error(
             "{{type}} object has no attribute {{item}}, did you .register_ops() for {{type}}?",
             type=self.__class__.__name__,
-            item=item
+            item=item,
         )
-
