@@ -17,6 +17,7 @@ from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.true_op import TRUE
 from jx_base.language import is_op
+from mo_imports import export
 from mo_json import BOOLEAN
 
 
@@ -91,4 +92,4 @@ class OrOp(Expression):
         return self.lang[OrOp(terms)]
 
 
-and_op.OrOp = OrOp
+export("jx_base.expressions.and_op", OrOp)
