@@ -8,6 +8,8 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
+from __future__ import absolute_import, division, unicode_literals
+
 from copy import copy
 from datetime import datetime
 from decimal import Decimal
@@ -15,7 +17,7 @@ from math import isnan
 
 from mo_dots import Data, data_types, listwrap, NullType, startswith_field
 from mo_dots.lists import list_types, is_many
-from mo_future import boolean_type, long, none_type, text, transpose
+from mo_future import boolean_type, long, none_type, text, transpose, function_type
 from mo_logs import Log
 from mo_times import Date
 
@@ -156,6 +158,9 @@ def value_compare(left, right, ordering=1):
     :return: The return value is negative if x < y, zero if x == y and strictly positive if x > y.
     """
 
+    if left is right:
+        return 0
+
     try:
         ltype = left.__class__
         rtype = right.__class__
@@ -208,6 +213,8 @@ def value_compare(left, right, ordering=1):
                 if c != 0:
                     return c
             return 0
+        elif ltype is function_type:
+             return 0
         elif left > right:
             return ordering
         elif left < right:
