@@ -9,7 +9,7 @@
 #
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.query import QueryOp
+from jx_base.expressions import QueryOp
 from mo_dots import is_data
 
 
@@ -58,4 +58,3 @@ def convert_list(operator, operand):
     else:
         return list(map(operator, operand))
 
-
