@@ -10,13 +10,16 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base import query
+import mo_dots
+import mo_math
 from jx_base.container import Container
 from jx_base.expressions import FALSE, TRUE
-from jx_base.query import QueryOp, _normalize_selects
+from jx_base.expressions import QueryOp
+from jx_base.expressions.query_op import _normalize_selects, _normalize_sort
 from jx_base.language import is_op, value_compare
 from jx_python import expressions as _expressions, flat_list, group_by
 from jx_python.containers.cube import Cube
+from jx_python.containers.list import ListContainer
 from jx_python.convert import list2table, list2cube
 from jx_python.cubes.aggs import cube_aggs
 from jx_python.expression_compiler import compile_expression
@@ -24,12 +27,13 @@ from jx_python.expressions import jx_expression_to_function as get
 from jx_python.flat_list import PartFlatList
 from mo_collections.index import Index
 from mo_collections.unique_index import UniqueIndex
-import mo_dots
-from mo_dots import Data, FlatList, Null, coalesce, is_container, is_data, is_list, is_many, join_field, listwrap, set_default, split_field, unwrap, to_data, dict_to_data, list_to_data
+from mo_dots import Data, FlatList, Null, coalesce, is_container, is_data, is_list, is_many, join_field, listwrap, \
+    set_default, split_field, unwrap, to_data, dict_to_data, list_to_data
+from mo_dots import _getdefault
 from mo_dots.objects import DataObject
 from mo_future import is_text, sort_using_cmp
+from mo_imports import export
 from mo_logs import Log
-import mo_math
 from mo_math import MIN, UNION
 
 # A COLLECTION OF DATABASE OPERATORS (RELATIONAL ALGEBRA OPERATORS)
@@ -53,16 +57,16 @@ def run(query, container=Null):
         container = to_data(query)["from"]
         query_op = QueryOp.wrap(query, container=container, namespace=container.schema)
     else:
-        query_op = QueryOp.wrap(query, container, container.namespace)
+        query_op = QueryOp.wrap(query, container=container, namespace=container.namespace)
 
     if container == None:
-        from jx_python.containers.list_usingPythonList import DUAL
+        from jx_python.containers.list import DUAL
 
         return DUAL.query(query_op)
     elif isinstance(container, Container):
         return container.query(query_op)
     elif is_many(container):
-        container = to_data(list(container))
+        container = ListContainer(name=None, data=list(container))
     elif isinstance(container, Cube):
         if is_aggs(query_op):
             return cube_aggs(container, query_op)
@@ -218,7 +222,10 @@ def tuple(data, field_name):
         else:
             path = split_field(field_name)
             output = []
-            flat_list._tuple1(data, path, 0, output)
+            for d in data:
+                for p in path:
+                    d = _getdefault(d, p)
+                    output.append((d,))
             return output
     elif is_list(field_name):
         paths = [_select_a_field(f) for f in field_name]
@@ -284,9 +291,6 @@ def select(data, field_name):
             data._data.values()
         )  # THE SELECT ROUTINE REQUIRES dicts, NOT Data WHILE ITERATING
 
-    if is_data(data):
-        return select_one(data, field_name)
-
     if is_data(field_name):
         field_name = to_data(field_name)
         if field_name.value in ["*", "."]:
@@ -556,7 +560,7 @@ def sort(data, fieldnames=None, already_normalized=False):
             if already_normalized:
                 formal = fieldnames
             else:
-                formal = query._normalize_sort(fieldnames)
+                formal = _normalize_sort(fieldnames)
 
             funcs = [(get(f.value), f.sort) for f in formal]
 
@@ -626,7 +630,10 @@ def pairwise(values):
     RETURN [(a, b), (b, c), (c, d), ...]
     """
     i = iter(values)
-    a = next(i)
+    try:
+        a = next(i)
+    except StopIteration:
+        return
 
     for b in i:
         yield (a, b)
@@ -1128,3 +1135,7 @@ def countdown(vals):
 
 
 from jx_python.lists.aggs import is_aggs, list_aggs
+
+
+export("jx_base.container", run)
+export("jx_python.containers.list", "jx")
